@@ -1,9 +1,9 @@
 # frozen_string_literal: true
-require 'zlib'
 require 'base64'
+require 'json'
+require 'zlib'
 
 require 'raven/version'
-require 'raven/okjson'
 require 'raven/transports/http'
 
 module Raven
@@ -22,7 +22,7 @@ module Raven
     end
 
     def send_event(event)
-      return false unless configuration_allows_sending
+      return false unless configuration.sending_allowed?(event)
 
       # Convert to hash
       event = event.to_hash
@@ -32,13 +32,13 @@ module Raven
         return
       end
 
-      Raven.logger.debug "Sending event #{event[:event_id]} to Sentry"
+      configuration.logger.info "Sending event #{event[:event_id]} to Sentry"
 
       content_type, encoded_data = encode(event)
 
       begin
         transport.send_event(generate_auth_header, encoded_data,
-                       :content_type => content_type)
+                             :content_type => content_type)
         successful_send
       rescue => e
         failed_send(e, event)
@@ -62,18 +62,9 @@ module Raven
 
     private
 
-    def configuration_allows_sending
-      if configuration.send_in_current_environment?
-        true
-      else
-        configuration.log_excluded_environment_message
-        false
-      end
-    end
-
     def encode(event)
-      hash = @processors.reduce(event.to_hash) { |memo, p| p.process(memo) }
-      encoded = OkJson.encode(hash)
+      hash = @processors.reduce(event.to_hash) { |a, e| e.process(a) }
+      encoded = JSON.fast_generate(hash)
 
       case configuration.encoding
       when 'gzip'
@@ -106,12 +97,11 @@ module Raven
     def failed_send(e, event)
       @state.failure
       if e # exception was raised
-        Raven.logger.error "Unable to record event with remote Sentry server (#{e.class} - #{e.message})"
-        e.backtrace[0..10].each { |line| Raven.logger.error(line) }
+        configuration.logger.error "Unable to record event with remote Sentry server (#{e.class} - #{e.message}):\n#{e.backtrace[0..10].join("\n")}"
       else
-        Raven.logger.error "Not sending event due to previous failure(s)."
+        configuration.logger.error "Not sending event due to previous failure(s)."
       end
-      Raven.logger.error("Failed to submit event: #{get_log_message(event)}")
+      configuration.logger.error("Failed to submit event: #{get_log_message(event)}")
       configuration.transport_failure_callback.call(event) if configuration.transport_failure_callback
     end
   end
@@ -124,7 +114,7 @@ module Raven
     def should_try?
       return true if @status == :online
 
-      interval = @retry_after || [@retry_number, 6].min ** 2
+      interval = @retry_after || [@retry_number, 6].min**2
       return true if Time.now - @last_check >= interval
 
       false
