@@ -19,6 +19,9 @@ module Raven
     }.freeze
 
     BACKTRACE_RE = /^(.+?):(\d+)(?::in `(.+?)')?$/
+    # See Sentry server default limits at
+    # https://github.com/getsentry/sentry/blob/master/src/sentry/conf/server.py
+    MAX_MESSAGE_SIZE_IN_BYTES = 1024 * 8
 
     PLATFORM = "ruby".freeze
     SDK = { "name" => "raven-ruby", "version" => Raven::VERSION }.freeze
@@ -38,7 +41,7 @@ module Raven
       @timestamp     = Time.now.utc
       @time_spent    = nil
       @level         = :error
-      @logger        = ''
+      @logger        = 'ruby'
       @culprit       = nil
       @server_name   = @configuration.server_name
       @release       = @configuration.release
@@ -106,7 +109,7 @@ module Raven
 
         new(options) do |evt|
           evt.configuration = configuration
-          evt.message = "#{exc.class}: #{exc.message}".byteslice(0...10_000) # Messages limited to 10kb
+          evt.message = "#{exc.class}: #{exc.message}".byteslice(0...MAX_MESSAGE_SIZE_IN_BYTES) # Messages limited to 10kb
           evt.level = options[:level] || :error
 
           add_exception_interface(evt, exc)
@@ -116,7 +119,7 @@ module Raven
       end
 
       def from_message(message, options = {})
-        message = message.byteslice(0...10_000) # Messages limited to 10kb
+        message = message.byteslice(0...MAX_MESSAGE_SIZE_IN_BYTES)
         configuration = options[:configuration] || Raven.configuration
 
         new(options) do |evt|
@@ -276,7 +279,8 @@ module Raven
     end
 
     def to_json_compatible
-      JSON.parse(JSON.generate(to_hash))
+      cleaned_hash = async_json_processors.reduce(to_hash) { |a, e| e.process(a) }
+      JSON.parse(JSON.generate(cleaned_hash))
     end
 
     # For cross-language compat
@@ -299,5 +303,12 @@ module Raven
         :forwarded_for => context.rack_env["HTTP_X_FORWARDED_FOR"]
       ).calculate_ip
     end
+
+    def async_json_processors
+      [
+        Raven::Processor::RemoveCircularReferences,
+        Raven::Processor::UTF8Conversion
+      ].map { |v| v.new(self) }
+    end
   end
 end
