@@ -37,11 +37,6 @@ module Raven
     end
 
     config.after_initialize do
-      Raven.configure do |config|
-        config.project_root ||= ::Rails.root
-        config.release ||= config.detect_release # if project_root has changed, need to re-check
-      end
-
       if Raven.configuration.rails_activesupport_breadcrumbs
         require 'raven/breadcrumbs/activesupport'
         Raven::ActiveSupportBreadcrumbs.inject
@@ -63,6 +58,12 @@ module Raven
       end
     end
 
+    initializer 'raven.active_job' do
+      ActiveSupport.on_load :active_job do
+        require 'raven/integrations/rails/active_job'
+      end
+    end
+
     rake_tasks do
       require 'raven/integrations/tasks'
     end
