@@ -1,4 +1,4 @@
-require 'raven/interfaces'
+require 'raven/interface'
 
 module Raven
   class SingleExceptionInterface < Interface
@@ -9,9 +9,7 @@ module Raven
 
     def to_hash(*args)
       data = super(*args)
-      if data[:stacktrace]
-        data[:stacktrace] = data[:stacktrace].to_hash
-      end
+      data[:stacktrace] = data[:stacktrace].to_hash if data[:stacktrace]
       data
     end
   end
