@@ -37,7 +37,8 @@ module Raven
       end
 
       def filename
-        return nil if abs_path.nil?
+        return if abs_path.nil?
+        return @filename if @filename
 
         prefix =
           if under_project_root? && in_app
@@ -48,19 +49,7 @@ module Raven
             longest_load_path
           end
 
-        prefix ? abs_path[prefix.to_s.chomp(File::SEPARATOR).length + 1..-1] : abs_path
-      end
-
-      def under_project_root?
-        project_root && abs_path.start_with?(project_root)
-      end
-
-      def project_root
-        @project_root ||= Raven.configuration.project_root && Raven.configuration.project_root.to_s
-      end
-
-      def longest_load_path
-        $LOAD_PATH.select { |s| abs_path.start_with?(s.to_s) }.sort_by { |s| s.to_s.length }.last
+        @filename = prefix ? abs_path[prefix.to_s.chomp(File::SEPARATOR).length + 1..-1] : abs_path
       end
 
       def to_hash(*args)
@@ -72,6 +61,20 @@ module Raven
         data.delete(:context_line) unless context_line && !context_line.empty?
         data
       end
+
+      private
+
+      def under_project_root?
+        project_root && abs_path.start_with?(project_root)
+      end
+
+      def project_root
+        @project_root ||= Raven.configuration.project_root && Raven.configuration.project_root.to_s
+      end
+
+      def longest_load_path
+        $LOAD_PATH.select { |path| abs_path.start_with?(path.to_s) }.max_by(&:size)
+      end
     end
   end
 end
