@@ -9,14 +9,8 @@ module Raven
         @configuration = configuration
       end
 
-      def send_event #(auth_header, data, options = {})
-        raise NotImplementedError.new('Abstract method not implemented')
-      end
-
-      protected
-
-      def verify_configuration
-        configuration.verify!
+      def send_event # (auth_header, data, options = {})
+        raise NotImplementedError, 'Abstract method not implemented'
       end
     end
   end
