@@ -15,6 +15,10 @@ module Raven
       end
 
       def send_event(auth_header, data, options = {})
+        unless configuration.sending_allowed?
+          logger.debug("Event not sent: #{configuration.error_messages}")
+        end
+
         project_id = configuration[:project_id]
         path = configuration[:path] + "/"
 
@@ -23,16 +27,18 @@ module Raven
           req.headers['X-Sentry-Auth'] = auth_header
           req.body = data
         end
-      rescue Faraday::ClientError => ex
-        raise Raven::Error, ex.message
+      rescue Faraday::Error => ex
+        error_info = ex.message
+        if ex.response && ex.response[:headers]['x-sentry-error']
+          error_info += " Error in headers is: #{ex.response[:headers]['x-sentry-error']}"
+        end
+        raise Raven::Error, error_info
       end
 
       private
 
       def set_conn
-        verify_configuration
-
-        Raven.logger.debug "Raven HTTP Transport connecting to #{configuration.server}"
+        configuration.logger.debug "Raven HTTP Transport connecting to #{configuration.server}"
 
         ssl_configuration = configuration.ssl || {}
         ssl_configuration[:verify] = configuration.ssl_verification
@@ -42,6 +48,7 @@ module Raven
           :url => configuration[:server],
           :ssl => ssl_configuration
         ) do |builder|
+          configuration.faraday_builder.call(builder) if configuration.faraday_builder
           builder.response :raise_error
           builder.adapter(*adapter)
         end
