@@ -2,12 +2,6 @@ require 'spec_helper'
 require 'raven/integrations/rack'
 
 describe Raven::Rack do
-  before(:all) do
-    Raven.configure do |config|
-      config.dsn = 'dummy://12345:67890@sentry.localdomain:3000/sentry/42'
-    end
-  end
-
   it 'should capture exceptions' do
     exception = build_exception
     env = {}
@@ -103,6 +97,19 @@ describe Raven::Rack do
     expect(interface.headers["Version"]).to eq("HTTP/2.0")
   end
 
+  it 'does not fail if an object in the env cannot be cast to string' do
+    obj = Class.new do
+      def to_s
+        raise 'Could not stringify object!'
+      end
+    end.new
+
+    env = { "HTTP_FOO" => "BAR", "rails_object" => obj }
+    interface = Raven::HttpInterface.new
+
+    expect { interface.from_rack(env) }.to_not raise_error
+  end
+
   it 'should pass rack/lint' do
     env = Rack::MockRequest.env_for("/test")
 
