@@ -1,27 +1,16 @@
 require "spec_helper"
-require "rspec/rails"
-require "raven/transports/dummy"
-require "raven/integrations/rack"
-require "raven/integrations/rails"
 
-describe TestApp, :type => :request do
+describe "Rails Integration", :type => :request, :rails => true do
   before(:all) do
-    @original_configuration = Raven.configuration
-
-    Raven.configuration = Raven::Configuration.new.tap do |config|
-      config.dsn = 'dummy://12345:67890@sentry.localdomain:3000/sentry/42'
-      config.encoding = 'json'
-    end
+    require "rspec/rails"
+    require "raven/integrations/rack"
+    require "raven/integrations/rails"
 
     Rails.logger = Logger.new(nil)
     Rails.env = "production"
     TestApp.initialize!
   end
 
-  after(:all) do
-    Raven.configuration = @original_configuration
-  end
-
   after(:each) do
     Raven.client.transport.events = []
   end
@@ -50,7 +39,7 @@ describe TestApp, :type => :request do
   end
 
   it "sets Raven.configuration.project_root correctly" do
-    expect(Raven.configuration.project_root).to eq(Rails.root)
+    expect(Raven.configuration.project_root).to eq(Rails.root.to_s)
   end
 
   it "doesn't clobber a manually configured release" do
