@@ -19,7 +19,7 @@ describe Raven::Processor::RemoveCircularReferences do
     result = @processor.process(data)
     expect(result['data']).to eq('(...)')
     expect(result['ary'].first['x']).to eq('(...)')
-    expect(result['ary2']).not_to eq('(...)')
+    expect(result['ary2']).to eq("(...)")
     expect(result['leave intact']).to eq('not a circular reference' => true)
   end
 end
