@@ -1,7 +1,21 @@
 require 'sentry-raven-without-integrations'
+require 'raven/transports/dummy'
 
-require File.dirname(__FILE__) + "/support/test_rails_app/app.rb"
-require "rspec/rails"
+Raven.configure do |config|
+  config.dsn = "dummy://12345:67890@sentry.localdomain/sentry/42"
+  config.encoding = "json"
+  config.silence_ready = true
+  config.logger = Logger.new(nil)
+end
+
+if ENV["RAILS_VERSION"] && (ENV["RAILS_VERSION"].to_i == 0)
+  RSpec.configure do |config|
+    config.filter_run_excluding :rails => true
+  end
+else
+  require File.dirname(__FILE__) + "/support/test_rails_app/app.rb"
+  require "rspec/rails"
+end
 
 RSpec.configure do |config|
   config.mock_with(:rspec) { |mocks| mocks.verify_partial_doubles = true }
