@@ -1,10 +1,9 @@
 require 'rails'
-# require "active_model/railtie"
-# require "active_job/railtie"
 # require "active_record/railtie"
+require "action_view/railtie"
 require "action_controller/railtie"
 # require "action_mailer/railtie"
-require "action_view/railtie"
+require "active_job/railtie"
 # require "action_cable/engine"
 # require "sprockets/railtie"
 # require "rails/test_unit/railtie"
